@@ -13,7 +13,7 @@ use vars qw(
 	$Quiet
 	);
 
-$VERSION = '0.241';
+$VERSION = '0.242';
 
 @EXPORT_OK = qw( prompt find_files copy gitify content );
 %EXPORT_TAGS = (
@@ -84,13 +84,18 @@ sub find_files {
 
     my @files = ();
 
-    find( sub {
-        	return unless -f $_;
-        	return if $File::Find::name =~ m<(?:CVS|\.svn|\.git)>;
-			push( @files, $File::Find::name );
-    		}, $directory
+	my $wanted = sub {
+		return unless -f $_;
+		return if $_ =~ m<(?:CVS|\.svn|\.git)>;
+		push @files, File::Spec->canonpath( $File::Find::name );
+		};
+
+    my %options = (
+    	wanted => $wanted,
     	);
 
+    find( \%options, $directory );
+
     return @files;
 	}
 
@@ -103,7 +108,7 @@ Copy the file from one place to another.
 sub copy {
 	my( $input, $output, $hash ) = @_;
 
-	print "Opening input [$input] for output [$output]\n";
+	print STDERR "Opening input [$input] for output [$output]\n";
 
 	open my $in_fh,  '<', $input  or die "Could not open [$input]: $!\n";
 	open my $out_fh, '>', $output or warn "Could not open [$output]: $!\n";
@@ -112,10 +117,10 @@ sub copy {
 
 	while( readline $in_fh ) {
 		$count += s/%%SCRIPTDIST_(.*?)%%/$hash->{ lc $1 } || ''/gie;
-		print $out_fh $_
+		print {$out_fh} $_
 		}
 
-	print "Copied [$input] with $count replacements\n" unless $Quiet;
+	print STDERR "Copied [$input] with $count replacements\n" unless $Quiet;
 	}
 
 =item gitify()
